/**
 *  Copyright 2011 Carsten Gräf
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * 
 */

package de.twenty11.skysail.common.filters;

import java.util.Map;

/**
 * An AndFilter is a filter with FilterType "AND" with only one level of
 * subfilters
 * 
 * The value can be a list of further filters.
 * 
 * @author carsten
 * 
 */
public class EqualFilter extends AbstractFilter {

    private static final long serialVersionUID = 5698588843830786052L;

    public EqualFilter(String attribute, String value) {
        setFilterType(FilterType.EQUALITY_MATCH);
        setAttribute(attribute);
        setSubfilters(null);
        setValue(value);
    }

    @Override
    public String getValue(String attribute) {

        // TODO Auto-generated method stub
        return "";
    }

    @Override
    public boolean match(Map<String, String> properties) {
        for (String property : properties.keySet()) {
            if (property.equals(getAttribute())) {
                if (properties.get(property).equals(getValue())) {
                    return true;
                }
            }
        }
        return false;
    }

    @Override
    public String toString() {
        StringBuffer sb = new StringBuffer();
        sb.append("(");
        sb.append(getAttribute());
        sb.append("=");
        sb.append(getValue());
        sb.append(")");
        return sb.toString();
    }

}
